/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.ranger.db;

import java.util.ArrayList;
import java.util.List;

import javax.persistence.NoResultException;

import org.apache.ranger.common.db.BaseDao;
import org.apache.ranger.entity.XXServiceConfigMap;
import org.springframework.stereotype.Service;

@Service
public class XXServiceConfigMapDao extends BaseDao<XXServiceConfigMap> {

	public XXServiceConfigMapDao(RangerDaoManagerBase daoManager) {
		super(daoManager);
	}

	public List<XXServiceConfigMap> findByServiceId(Long serviceId) {
		if (serviceId == null) {
			return new ArrayList<XXServiceConfigMap>();
		}
		try {
			return getEntityManager()
					.createNamedQuery("XXServiceConfigMap.findByServiceId", tClass)
					.setParameter("serviceId", serviceId)
					.getResultList();
		} catch (NoResultException e) {
			return new ArrayList<XXServiceConfigMap>();
		}
	}

	public XXServiceConfigMap findByServiceAndConfigKey(Long serviceId,
			String configKey) {
		if(serviceId == null || configKey == null) {
			return null;
		}
		try {
			return getEntityManager()
					.createNamedQuery("XXServiceConfigMap.findByServiceAndConfigKey", tClass)
					.setParameter("serviceId", serviceId)
					.setParameter("configKey", configKey).getSingleResult();
		} catch (NoResultException e) {
			return null;
		}
	}

	public XXServiceConfigMap findByServiceNameAndConfigKey(String serviceName, String configKey) {
		if(serviceName == null || configKey == null) {
			return null;
		}
		try {
			return getEntityManager()
					.createNamedQuery("XXServiceConfigMap.findByServiceNameAndConfigKey", tClass)
					.setParameter("name", serviceName)
					.setParameter("configKey", configKey).getSingleResult();
		} catch (NoResultException e) {
			return null;
		}
	}

}
